# opcua-tools
Python/pandas-based tools for OPC UA information models. 
OPC UA information models are represented and manipulated in Pandas Dataframes. 
There is a parser from NodeSet2 XML files, functions for manipulating/extracting information from information models and a NodeSet2 generator. 
There are some general tests here, but most of the testing is indirect through its use in [quarry](https://github.com/PrediktorAS/quarry) and other internal tools.
## Installation
To install, run this command: 
```
pip install git+https://github.com/PrediktorAS/opcua-tools.git
```
## Usage
Forthcoming... see the test cases. 

## License
The code in this repository is copyrighted to [Prediktor AS](http://prediktor.com), and is licensed under the Apache 2.0 license. \
Exceptions apply to some of the test data and static files for parsing/generation (see document headers for license information). 

Author:
[Magnus Bakken](mba@prediktor.com)